@@ -15,6 +15,7 @@ from je_api_testka.utils.generate_report.json_report import generate_json_report
 from je_api_testka.utils.generate_report.xml_report import generate_xml
 from je_api_testka.utils.generate_report.xml_report import generate_xml_report
 from je_api_testka.utils.json.json_file.json_file import read_action_json
+from je_api_testka.utils.package_manager.package_manager_class import package_manager
 
 
 class Executor(object):
@@ -32,6 +33,7 @@ class Executor(object):
             # execute
             "execute_action": self.execute_action,
             "execute_files": self.execute_files,
+            "add_package_to_executor": package_manager.add_package_to_executor,
         }
         # get all time module builtin function and add to event dict
         for function in getmembers(time, isbuiltin):
@@ -97,6 +99,7 @@ class Executor(object):
 
 
 executor = Executor()
+package_manager.executor = executor
 
 
 def add_command_to_executor(command_dict: dict):
